.. module:: enaml.widgets.notebook

======================
enaml.widgets.notebook
======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Notebook


.. autoclass:: Notebook
